"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.prepareTemplate = prepareTemplate;

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _replace = _interopRequireDefault(require("replace"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Remove the `.git` dir, licenses and rename the app name and registry.
 * (It will search and replace anything that matches `placeholder-app-name`)
 *
 * @param {string} dir - for example `foo`
 * @param {string} appName - for example `foo.myApmRegistry.eth`
 * @returns {void}
 */
async function prepareTemplate(dirPath, basename, appName) {
  const projectPath = `${dirPath}/${basename}`;
  /**
   * Delete .git
   */

  const gitFolderPath = _path.default.resolve(projectPath, '.git');
  /**
   * Delete licenses
   */


  const licensePath = _path.default.resolve(projectPath, 'LICENSE');

  const packageJsonPath = _path.default.resolve(projectPath, 'package.json');

  const packageJson = await _fsExtra.default.readJson(packageJsonPath);
  delete packageJson.license;
  await _fsExtra.default.writeJson(packageJsonPath, packageJson, {
    spaces: 2
  });
  /**
   * Replace the default registries with the preferred one
   */

  const defaultRegistries = [// To keep backwards compatibility, only change `aragonpm.eth`, leave `open.aragonpm.eth`
  'placeholder-app-name.aragonpm.eth' // 'placeholder-app-name.open.aragonpm.eth',
  ];
  defaultRegistries.forEach(registry => {
    (0, _replace.default)({
      regex: registry,
      replacement: appName,
      paths: [projectPath],
      recursive: true,
      silent: true
    });
  });
  /**
   * Replace the placeholder name with the actual name
   */

  (0, _replace.default)({
    regex: 'placeholder-app-name',
    replacement: basename,
    paths: [projectPath],
    recursive: true,
    silent: true
  });
  return Promise.all([_fsExtra.default.remove(gitFolderPath), _fsExtra.default.remove(licensePath)]);
}
//# sourceMappingURL=prepare-template.js.map