"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  configure: true,
  middleware: true,
  errorHandler: true
};
exports.errorHandler = exports.middleware = exports.configure = void 0;

var _ConsoleReporter = _interopRequireDefault(require("./ConsoleReporter"));

var _ReporterIcons = require("./ReporterIcons");

Object.keys(_ReporterIcons).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _ReporterIcons[key];
    }
  });
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// TODO FileReporter: save "--debug" output as logs in ~/.aragon
const configure = yargs => yargs.option('silent', {
  boolean: true,
  description: 'Silence all output',
  default: false
}).option('debug', {
  boolean: true,
  description: 'Show extra output',
  default: false
}).alias('s', 'silent').alias('d', 'debug').group(['debug', 'silent'], 'Global options:').middleware([middleware]);

exports.configure = configure;

const middleware = argv => {
  const {
    silent,
    debug
  } = argv;
  const reporter = new _ConsoleReporter.default({
    silent,
    debug
  });
  return {
    reporter
  };
};

exports.middleware = middleware;

const errorHandler = (msg, err) => {
  const {
    argv
  } = process;

  if (argv.includes('--silent') || argv.includes('--s')) {
    return process.exit(1);
  } // an error from yargs


  if (msg) {
    console.error(_ReporterIcons.ERROR_ICON, msg);
    console.error(_ReporterIcons.WARNING_ICON, 'Use --help to show the available commands');
    return process.exit(1);
  } // an error that was thrown and which has a stack


  if (argv.includes('--debug') || argv.includes('--d')) {
    // errors thrown by listr have a context property which makes printing less nice
    delete err.context;
    console.error(_ReporterIcons.ERROR_ICON, err);
  } else {
    console.error(_ReporterIcons.ERROR_ICON, err.message);
  }

  return process.exit(1);
};

exports.errorHandler = errorHandler;
//# sourceMappingURL=AragonReporter.js.map